==> chromium_78.0.3904.108.orig.tar.xz: chromium-78.0.3904.108/chrome/browser/notifications/scheduler/internal/notification_schedule_service_impl.cc <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/notifications/scheduler/internal/notification_schedule_service_impl.h"

#include <utility>

#include "base/bind.h"
#include "base/logging.h"
#include "chrome/browser/notifications/scheduler/internal/notification_scheduler.h"
#include "chrome/browser/notifications/scheduler/internal/stats.h"
#include "chrome/browser/notifications/scheduler/public/notification_params.h"

namespace notifications {

NotificationScheduleServiceImpl::NotificationScheduleServiceImpl(
    std::unique_ptr<NotificationScheduler> scheduler)
    : scheduler_(std::move(scheduler)) {
  scheduler_->Init(
      base::BindOnce(&NotificationScheduleServiceImpl::OnInitialized,
                     weak_ptr_factory_.GetWeakPtr()));
}

NotificationScheduleServiceImpl::~NotificationScheduleServiceImpl() = default;

void NotificationScheduleServiceImpl::Schedule(
    std::unique_ptr<NotificationParams> notification_params) {
  scheduler_->Schedule(std::move(notification_params));
}

void NotificationScheduleServiceImpl::DeleteNotifications(
    SchedulerClientType type) {
  scheduler_->DeleteAllNotifications(type);
}

void NotificationScheduleServiceImpl::GetImpressionDetail(
    SchedulerClientType type,
    ImpressionDetail::ImpressionDetailCallback callback) {
  scheduler_->GetImpressionDetail(type, std::move(callback));
}

NotificationBackgroundTaskScheduler::Handler*
NotificationScheduleServiceImpl::GetBackgroundTaskSchedulerHandler() {
  return this;
}

UserActionHandler* NotificationScheduleServiceImpl::GetUserActionHandler() {
  return this;
}

void NotificationScheduleServiceImpl::OnStartTask(
    SchedulerTaskTime task_time,
    TaskFinishedCallback callback) {
  scheduler_->OnStartTask(task_time, std::move(callback));
}

void NotificationScheduleServiceImpl::OnStopTask(SchedulerTaskTime task_time) {
  scheduler_->OnStopTask(task_time);
}

void NotificationScheduleServiceImpl::OnUserAction(
    const UserActionData& action_data) {
  stats::LogUserAction(action_data);
  scheduler_->OnUserAction(action_data);
}

void NotificationScheduleServiceImpl::OnInitialized(bool success) {
  // TODO(xingliu): Track metric here.
  NOTIMPLEMENTED();
}

}  // namespace notifications

==> chromium_79.0.3945.130.orig.tar.xz: chromium-79.0.3945.130/chrome/browser/notifications/scheduler/internal/notification_schedule_service_impl.cc <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/notifications/scheduler/internal/notification_schedule_service_impl.h"

#include <utility>

#include "base/bind.h"
#include "base/logging.h"
#include "chrome/browser/notifications/scheduler/internal/notification_scheduler.h"
#include "chrome/browser/notifications/scheduler/internal/stats.h"
#include "chrome/browser/notifications/scheduler/public/notification_params.h"

namespace notifications {

NotificationScheduleServiceImpl::NotificationScheduleServiceImpl(
    std::unique_ptr<NotificationScheduler> scheduler)
    : scheduler_(std::move(scheduler)) {
  scheduler_->Init(
      base::BindOnce(&NotificationScheduleServiceImpl::OnInitialized,
                     weak_ptr_factory_.GetWeakPtr()));
}

NotificationScheduleServiceImpl::~NotificationScheduleServiceImpl() = default;

void NotificationScheduleServiceImpl::Schedule(
    std::unique_ptr<NotificationParams> notification_params) {
  scheduler_->Schedule(std::move(notification_params));
}

void NotificationScheduleServiceImpl::DeleteNotifications(
    SchedulerClientType type) {
  scheduler_->DeleteAllNotifications(type);
}

void NotificationScheduleServiceImpl::GetImpressionDetail(
    SchedulerClientType type,
    ImpressionDetail::ImpressionDetailCallback callback) {
  scheduler_->GetImpressionDetail(type, std::move(callback));
}

NotificationBackgroundTaskScheduler::Handler*
NotificationScheduleServiceImpl::GetBackgroundTaskSchedulerHandler() {
  return this;
}

UserActionHandler* NotificationScheduleServiceImpl::GetUserActionHandler() {
  return this;
}

void NotificationScheduleServiceImpl::OnStartTask(
    TaskFinishedCallback callback) {
  scheduler_->OnStartTask(std::move(callback));
}

void NotificationScheduleServiceImpl::OnStopTask() {
  scheduler_->OnStopTask();
}

void NotificationScheduleServiceImpl::OnUserAction(
    const UserActionData& action_data) {
  stats::LogUserAction(action_data);
  scheduler_->OnUserAction(action_data);
}

void NotificationScheduleServiceImpl::OnInitialized(bool success) {
  // TODO(xingliu): Track metric here.
  NOTIMPLEMENTED();
}

}  // namespace notifications
